@@ -301,12 +301,17 @@ class RuleICRV(Rule):
     :class:`RuleCondorcetVtbIRV`.
     """
 
+    full_name = 'Benham'
+    abbreviation = 'Ben'
+
+    options_parameters = Rule.options_parameters.copy()
+    options_parameters.update({
+        'cm_option': {'allowed': {'fast', 'slow', 'very_slow', 'exact'}, 'default': 'fast'},
+        'icm_option': {'allowed': ['exact'], 'default': 'exact'},
+    })
+
     def __init__(self, **kwargs):
         super().__init__(
-            options_parameters={
-                'cm_option': {'allowed': {'fast', 'slow', 'very_slow', 'exact'}, 'default': 'fast'},
-                'icm_option': {'allowed': ['exact'], 'default': 'exact'},
-            },
             with_two_candidates_reduces_to_plurality=True, is_based_on_rk=True,
             precheck_icm=False,
             log_identity="ICRV", **kwargs
