@@ -4,12 +4,14 @@ from svvamp import Profile
 
 def test_not_enough_voters():
     with pytest.raises(ValueError):
-        _ = Profile(preferences_ut=[[1, 0]])
+        profile = Profile(preferences_ut=[[1, 0]])
+        _ = profile.n_v
 
 
 def test_not_enough_candidates():
     with pytest.raises(ValueError):
-        _ = Profile(preferences_ut=[[1], [0]])
+        profile = Profile(preferences_ut=[[1], [0]])
+        _ = profile.n_c
 
 
 def test_set_labels_candidates():
